@@ -153,7 +153,7 @@ pub fn get_args(version: &str) -> ArgMatches {
                     Arg::with_name("output")
                         .short("o")
                         .long("output")
-                        .help("Uses a costume output filename")
+                        .help("Uses a costume output directory")
                         .takes_value(true)
                         .required(true)
                         .default_value("concat")
@@ -176,6 +176,13 @@ pub fn get_args(version: &str) -> ArgMatches {
                             "phylip-int",
                         ]),
                 )
+                .arg(
+                    Arg::with_name("prefix")
+                        .long("prefix")
+                        .help("Uses a costume output filename")
+                        .takes_value(true)
+                        .value_name("PREFIX"),
+                )
                 .arg(
                     Arg::with_name("datatype")
                         .long("datatype")
@@ -298,6 +305,14 @@ pub fn get_args(version: &str) -> ArgMatches {
                             "phylip-int",
                         ]),
                 )
+                .arg(
+                    Arg::with_name("prefix")
+                        .long("prefix")
+                        .help("Uses a costume output filename")
+                        .takes_value(true)
+                        .requires("concat")
+                        .value_name("PREFIX"),
+                )
                 .arg(
                     Arg::with_name("partition")
                         .short("-p")
@@ -307,7 +322,6 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .requires_all(&[
                             "concat",
                             "output",
-                            "output-format",
                         ])
                         .value_name("FORMAT")
                         .possible_values(&["charset", "nexus", "raxml"]),
@@ -319,7 +333,6 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .requires_all(&[
                             "partition",
                             "output",
-                            "output-format",
                         ])
                         .takes_value(false),
                 )
