@@ -10,7 +10,7 @@ use crate::helper::types::{DataType, InputFmt, OutputFmt};
 impl InputCli for FilterParser<'_> {}
 impl InputPrint for FilterParser<'_> {}
 impl OutputCli for FilterParser<'_> {}
-impl PartCLi for FilterParser<'_> {}
+impl ConcatCLi for FilterParser<'_> {}
 
 pub(in crate::cli) struct FilterParser<'a> {
     matches: &'a ArgMatches<'a>,
@@ -50,33 +50,6 @@ impl<'a> FilterParser<'a> {
         } else {
             self.parse_input_wcard(self.matches)
         };
-
-        if self.is_npercent() {
-            self.get_min_taxa_npercent(task_desc);
-        } else {
-            self.get_params();
-            self.set_output_path();
-            self.filter_aln(task_desc);
-        }
-    }
-
-    fn get_min_taxa_npercent(&mut self, task_desc: &str) {
-        let npercent = self.parse_npercent();
-        npercent.iter().for_each(|&np| {
-            self.percent = np;
-            let min_tax = self.get_min_taxa();
-            self.params = Params::MinTax(min_tax);
-            self.set_multi_output_path();
-            self.filter_aln(task_desc);
-            utils::print_divider();
-        });
-    }
-
-    fn is_input_dir(&self) -> bool {
-        self.matches.is_present("dir")
-    }
-
-    fn filter_aln(&self, task_desc: &str) {
         self.print_input_multi(
             &self.input_dir,
             task_desc,
@@ -84,8 +57,32 @@ impl<'a> FilterParser<'a> {
             &self.input_fmt,
             &self.datatype,
         );
+
+        if self.is_npercent() {
+            self.get_min_taxa_npercent();
+        } else {
+            self.get_params();
+            self.set_output_path();
+            self.filter_aln();
+        }
+    }
+
+    fn get_min_taxa_npercent(&mut self) {
+        let npercent = self.parse_npercent();
+        self.count_ntax();
+        npercent.iter().for_each(|&np| {
+            self.percent = np;
+            let min_taxa = self.count_min_tax();
+            self.params = Params::MinTax(min_taxa);
+            self.set_multi_output_path();
+            self.filter_aln();
+            utils::print_divider();
+        });
+    }
+
+    fn filter_aln(&self) {
+        self.check_output_dir_exist(&self.output_dir);
         self.print_params();
-        check_output_dir_exist(&self.output_dir);
         let mut filter = SeqFilter::new(
             &self.files,
             &self.input_fmt,
@@ -100,8 +97,9 @@ impl<'a> FilterParser<'a> {
                 } else {
                     OutputFmt::Nexus
                 };
-                let fname = self.create_fname(&self.output_dir, &output_fmt);
-                let output = self.output_dir.join(fname);
+                let prefix = self.parse_prefix(self.matches, &self.output_dir);
+                let final_path = self.output_dir.join(prefix);
+                let output = self.create_output_fname(&final_path, &output_fmt);
                 filter.set_concat(&output, &output_fmt, &part_fmt);
                 filter.filter_aln();
             }
@@ -113,7 +111,9 @@ impl<'a> FilterParser<'a> {
         self.params = match self.matches {
             m if m.is_present("percent") => {
                 self.percent = self.get_percent();
-                Params::MinTax(self.get_min_taxa())
+                self.count_ntax();
+                let min_taxa = self.count_min_tax();
+                Params::MinTax(min_taxa)
             }
             m if m.is_present("aln-len") => Params::AlnLen(self.get_aln_len()),
             m if m.is_present("pars-inf") => Params::ParsInf(self.get_pars_inf()),
@@ -121,11 +121,6 @@ impl<'a> FilterParser<'a> {
         }
     }
 
-    fn get_min_taxa(&mut self) -> usize {
-        self.get_ntax();
-        self.count_min_tax()
-    }
-
     fn check_concat(&self) -> Option<PartitionFmt> {
         if self.matches.is_present("concat") {
             Some(self.get_part_fmt())
@@ -160,13 +155,16 @@ impl<'a> FilterParser<'a> {
             .expect("Failed parsing a parsimony informative value to in integer")
     }
 
-    fn get_ntax(&mut self) {
-        self.ntax = if self.matches.is_present("ntax") {
-            self.parse_ntax()
+    fn count_ntax(&mut self) {
+        if self.matches.is_present("ntax") {
+            self.ntax = self.parse_ntax();
         } else {
-            IDs::new(&self.files, &self.input_fmt, &self.datatype)
+            let spin = utils::set_spinner();
+            spin.set_message("Counting the number of taxa...");
+            self.ntax = IDs::new(&self.files, &self.input_fmt, &self.datatype)
                 .get_id_all()
-                .len()
+                .len();
+            spin.finish_with_message("DONE!\n");
         };
     }
 
@@ -182,10 +180,6 @@ impl<'a> FilterParser<'a> {
             .collect()
     }
 
-    fn is_npercent(&mut self) -> bool {
-        self.matches.is_present("npercent")
-    }
-
     fn get_percent(&mut self) -> f64 {
         let percent = self
             .matches
@@ -258,6 +252,14 @@ impl<'a> FilterParser<'a> {
             Params::ParsInf(inf) => log::info!("{:18}: {}\n", "Min pars. inf", inf),
         }
     }
+
+    fn is_npercent(&mut self) -> bool {
+        self.matches.is_present("npercent")
+    }
+
+    fn is_input_dir(&self) -> bool {
+        self.matches.is_present("dir")
+    }
 }
 
 #[cfg(test)]
